import React, { useState } from "react";
import LoginCard from "./LoginCard";
import { useToast } from "../../../hooks";
import { useTranslation } from "react-i18next";
import { useTuitioClient } from "@flare/tuitio-client-react";

const LoginContainer = () => {
  const [credentials, setCredentials] = useState({
    userName: "",
    password: ""
  });

  const { error } = useToast();
  const { t } = useTranslation();
  const { login } = useTuitioClient({
    onLoginFailed: () => error(t("Login.IncorrectCredentials")),
    onLoginError: err => error(err.message)
  });

  const handleChange = prop => event => {
    setCredentials(prev => ({ ...prev, [prop]: event.target.value }));
  };

  const handleLogin = () => {
    const { userName, password } = credentials;
    return login(userName, password);
  };

  return (
    <LoginCard
      credentials={credentials}
      onChange={handleChange}
      onLogin={handleLogin}
    />
  );
};

export default LoginContainer;
