import React, { useMemo } from "react";
import PropTypes from "prop-types";
import {
  TableCell,
  TableRow,
  IconButton,
  Collapse,
  Menu
} from "@material-ui/core";
import { KeyboardArrowDown, KeyboardArrowUp } from "@material-ui/icons";
import { makeStyles } from "@material-ui/core/styles";
import MachineLog from "./common/MachineLog";
import WakeComponent from "./common/WakeComponent";
import ActionButton from "./common/ActionButton";
import { useSensitiveInfo } from "../../../hooks";

const useRowStyles = makeStyles({
  root: {
    "& > *": {
      borderBottom: "unset"
    }
  }
});

const Machine = ({
  machine,
  actions,
  logs,
  addLog,
  secondaryActionsMenuProps
}) => {
  const [open, setOpen] = React.useState(false);
  const classes = useRowStyles();
  const { mask, maskElements } = useSensitiveInfo();

  const topActions = useMemo(
    () => actions.filter(a => a.top === true),
    [actions]
  );

  const secondaryActions = useMemo(
    () => actions.filter(a => a.top === false),
    [actions]
  );

  return (
    <React.Fragment>
      <TableRow className={classes.root}>
        <TableCell>
          <IconButton
            aria-label="expand row"
            size="small"
            onClick={() => setOpen(!open)}
          >
            {open ? <KeyboardArrowUp /> : <KeyboardArrowDown />}
          </IconButton>
        </TableCell>
        <TableCell component="th" scope="row">
          {mask(machine.fullMachineName)}
        </TableCell>
        <TableCell>{mask(machine.machineName)}</TableCell>
        <TableCell>{mask(machine.iPv4Address)}</TableCell>
        <TableCell>{mask(machine.macAddress)}</TableCell>
        <TableCell align="right">
          <WakeComponent machine={machine} addLog={addLog} />
          {topActions.map(action => (
            <ActionButton
              key={`machine-item-${machine.machineId}-${action.code}`}
              action={action}
              machine={machine}
            />
          ))}
          <Menu
            id="secondary-actions-menu"
            anchorEl={secondaryActionsMenuProps.anchor}
            keepMounted
            open={Boolean(secondaryActionsMenuProps.anchor)}
            onClose={secondaryActionsMenuProps.onCloseSecondaryActions}
          >
            {secondaryActions.map(action => (
              <ActionButton
                key={`machine-item-${machine.machineId}-${action.code}`}
                action={action}
                machine={machine}
              />
            ))}
          </Menu>
        </TableCell>
      </TableRow>
      <TableRow>
        <TableCell style={{ paddingBottom: 0, paddingTop: 0 }} colSpan={6}>
          <Collapse in={open} timeout="auto" unmountOnExit>
            <MachineLog logs={maskElements(logs)} />
          </Collapse>
        </TableCell>
      </TableRow>
    </React.Fragment>
  );
};

Machine.propTypes = {
  machine: PropTypes.shape({
    machineId: PropTypes.number.isRequired,
    machineName: PropTypes.string.isRequired,
    fullMachineName: PropTypes.string.isRequired,
    macAddress: PropTypes.string.isRequired,
    iPv4Address: PropTypes.string,
    description: PropTypes.string
  }).isRequired,
  actions: PropTypes.array.isRequired,
  logs: PropTypes.array.isRequired,
  addLog: PropTypes.func.isRequired,
  secondaryActionsMenuProps: PropTypes.object.isRequired
};

export default Machine;
