import React, { useContext, useEffect, useCallback, useState } from "react";
import {
  NetworkStateContext,
  NetworkDispatchContext
} from "../../network/state/contexts";
import useApi from "../../../api";
import MachinesListComponent from "./MachinesListComponent";
import PageTitle from "../../../components/common/PageTitle";
import { useTranslation } from "react-i18next";
import ViewModeSelection, { ViewModes } from "./ViewModeSelection";

const MachinesContainer = () => {
  const [viewMode, setViewMode] = useState(ViewModes.TABLE);

  const state = useContext(NetworkStateContext);
  const dispatchActions = useContext(NetworkDispatchContext);
  const { t } = useTranslation();

  const api = useApi();

  const handleReadMachines = useCallback(async () => {
    await api.readMachines({
      onCompleted: machines => {
        const data = Object.assign(machines, { loaded: true });
        dispatchActions.onNetworkChange("machines", data);
      }
    });
  }, [dispatchActions, api]);

  useEffect(() => {
    if (!state.network.machines.loaded) {
      handleReadMachines();
    }
  }, [handleReadMachines, state.network.machines.loaded]);

  return (
    <>
      <PageTitle
        text={t("Menu.Machines")}
        toolBar={<ViewModeSelection callback={setViewMode} />}
      />
      <MachinesListComponent
        machines={state.network.machines}
        viewMode={viewMode}
      />
    </>
  );
};

export default MachinesContainer;
