import React, { useState, useEffect, useCallback } from "react";
import PropTypes from "prop-types";
import TableChartIcon from "@material-ui/icons/TableChart";
import ViewListIcon from "@material-ui/icons/ViewList";
import ToggleButton from "@material-ui/lab/ToggleButton";
import ToggleButtonGroup from "@material-ui/lab/ToggleButtonGroup";
import { useWindowSize } from "@flare/react-hooks";

export const ViewModes = {
  TABLE: "table",
  ACCORDION: "accordion"
};

const ViewModeSelection = ({ callback }) => {
  const [viewMode, setViewMode] = useState(ViewModes.TABLE);
  const { isMobile } = useWindowSize();

  const handleViewModeSelection = useCallback(
    (event, mode) => {
      setViewMode(mode);
      callback && callback(mode);
    },
    [callback]
  );

  useEffect(
    () =>
      handleViewModeSelection(
        null,
        isMobile ? ViewModes.ACCORDION : ViewModes.TABLE
      ),
    [handleViewModeSelection, isMobile]
  );

  return (
    <ToggleButtonGroup
      size="small"
      value={viewMode}
      exclusive
      onChange={handleViewModeSelection}
    >
      <ToggleButton value={ViewModes.TABLE} aria-label="table view mode">
        <TableChartIcon />
      </ToggleButton>
      <ToggleButton
        value={ViewModes.ACCORDION}
        aria-label="accordion view mode"
      >
        <ViewListIcon />
      </ToggleButton>
    </ToggleButtonGroup>
  );
};

ViewModeSelection.propTypes = {
  initialMode: PropTypes.oneOf([ViewModes.TABLE, ViewModes.ACCORDION]),
  callback: PropTypes.func
};

export default ViewModeSelection;
